Name of a meta relationship (e.g. MR). Use meta_rels_list to get the full list of meta relationships.
limit
Max number of items to retrieve.
offset
Number of items to skip. Use limit and offset in combination to do pagination.
mode
If mode = "table", returns a data frame
(a tibble as per
tidyverse convention).
If mode = "raw", returns a raw response from EpiGraphDB API
with minimal parsing done by httr.